@@ -1,25 +1,24 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
 from fastapi.responses import UJSONResponse
 
-from hagworm.extend.base import Utils
 from hagworm.extend.struct import Result
 
+from .middleware import RequestIDMiddleware
+
 
 class Response(UJSONResponse):
 
     def __init__(self, content=None, status_code=200, *args, **kwargs):
 
-        self._request_id = Utils.uuid1_urn()
+        self._request_id = RequestIDMiddleware.get_request_id()
 
         super().__init__(content, status_code, *args, **kwargs)
 
-    @property
-    def request_id(self):
-
-        return self._request_id
-
     def render(self, content):
+
         return super().render(
             Result(data=content, request_id=self._request_id)
         )
@@ -35,6 +34,7 @@ class ErrorResponse(Response, Exception):
         Exception.__init__(self, self.body.decode())
 
     def render(self, content):
+
         return UJSONResponse.render(
             self,
             Result(code=self._error_code, data=content, request_id=self._request_id)
